        function getT(rr,cc){
       if(rr==5 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260503 a 00</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==5 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260503 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>5</strong> miembros: 24 <strong>control</strong><br>0,2,3,5,6,7,8,9,11,13,14,15,17,28,29,33,34,35,36,38,42,44,48,50';}
       if(rr==5 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260503 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>21</strong> miembros: 18 <br>1,10,12,16,18,19,20,21,22,23,24,26,27,31,37,41,46,49';}
       if(rr==5 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260503 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>3</strong> representante: <strong>40</strong> miembros: 9 <br>4,25,30,32,39,40,43,45,47';}
       if(rr==40 && cc==0){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260503 a 00</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==40 && cc==1){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260503 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>5</strong> miembros: 24 <strong>control</strong><br>0,2,3,5,6,7,8,9,11,13,14,15,17,28,29,33,34,35,36,38,42,44,48,50';}
       if(rr==40 && cc==2){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260503 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>21</strong> miembros: 18 <br>1,10,12,16,18,19,20,21,22,23,24,26,27,31,37,41,46,49';}
       if(rr==40 && cc==3){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260503 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>3</strong> representante: <strong>40</strong> miembros: 9 <br>4,25,30,32,39,40,43,45,47';}
       if(rr==41 && cc==0){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260503 a 00</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==41 && cc==1){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260503 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>5</strong> miembros: 24 <strong>control</strong><br>0,2,3,5,6,7,8,9,11,13,14,15,17,28,29,33,34,35,36,38,42,44,48,50';}
       if(rr==41 && cc==2){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260503 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>21</strong> miembros: 18 <br>1,10,12,16,18,19,20,21,22,23,24,26,27,31,37,41,46,49';}
       if(rr==41 && cc==3){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260503 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>3</strong> representante: <strong>40</strong> miembros: 9 <br>4,25,30,32,39,40,43,45,47';}
       if(rr==42 && cc==0){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260503 a 00</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==42 && cc==1){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260503 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>5</strong> miembros: 24 <strong>control</strong><br>0,2,3,5,6,7,8,9,11,13,14,15,17,28,29,33,34,35,36,38,42,44,48,50';}
       if(rr==42 && cc==2){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260503 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>21</strong> miembros: 18 <br>1,10,12,16,18,19,20,21,22,23,24,26,27,31,37,41,46,49';}
       if(rr==42 && cc==3){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260503 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>3</strong> representante: <strong>40</strong> miembros: 9 <br>4,25,30,32,39,40,43,45,47';}
       if(rr==43 && cc==0){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260503 a 00</strong> UTC HH+030 (rango:024-036)<br><strong>control +<br>EPS</strong>';}
       if(rr==43 && cc==1){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260503 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>1</strong> representante: <strong>5</strong> miembros: 24 <strong>control</strong><br>0,2,3,5,6,7,8,9,11,13,14,15,17,28,29,33,34,35,36,38,42,44,48,50';}
       if(rr==43 && cc==2){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260503 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>2</strong> representante: <strong>21</strong> miembros: 18 <br>1,10,12,16,18,19,20,21,22,23,24,26,27,31,37,41,46,49';}
       if(rr==43 && cc==3){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260503 a 00</strong> UTC HH+030 (rango:024-036)<br>grupo: <strong>3</strong> representante: <strong>40</strong> miembros: 9 <br>4,25,30,32,39,40,43,45,47';}
}
